#####################
Cogent Usage Examples
#####################

**************************************
A Note on the Computable Documentation
**************************************

The following examples are all available as standalone text files which can be computed using the Python doctest module.

*****************
Data manipulation
*****************

.. toctree::
    :maxdepth: 1

    translate_dna
    seq_features
    complete_seq_features
    reverse_complement
    align_codons_to_protein
    aln_profile
    genetic_code_aa_index
    handling_tabular_data
    query_ncbi
    query_ensembl
    manipulating_tree_nodes

**********************************
Controlling 3rd party applications
**********************************

.. toctree::
    :maxdepth: 1

    application_controller_framework
    alignment_app_controllers
    phylogeny_app_controllers
    generating_app_commandlines

*********************
General data analysis
*********************

.. toctree::
    :maxdepth: 1

    perform_PCoA_analysis
    perform_nmds
    motif_results

******************
Data Visualisation
******************

.. toctree::
    :maxdepth: 1

    draw_dendrogram
    draw_dotplot

*******************
Modelling Evolution
*******************

.. toctree::
    :maxdepth: 1

    simple
    relative_rate
    neutral_test
    scope_model_params_on_trees
    empirical_protein_models
    testing_multi_loci
    reuse_results
    unrestricted_nucleotide
    simulate_alignment
    parametric_bootstrap
    estimate_startingpoint
    coevolution
    rate_heterogeneity
    hmm_par_heterogeneity

***************************
Phylogenetic Reconstruction
***************************

.. toctree::
    :maxdepth: 1

    calculate_pairwise_distances
    calculate_neigbourjoining_tree
    calculate_UPGMA_cluster
    phylo_by_ls
    maketree_from_proteinseqs

